@@ -19,8 +19,12 @@ class CredentialManager(BaseObject):
             *   https://bast-ai.atlassian.net/browse/COR-8
         """
         BaseObject.__init__(self, __name__)
-        self._access_key = EnvIO.str_or_exception('AWS_ACCESS_KEY')
-        self._secret_key = EnvIO.str_or_exception('AWS_SECRET_KEY')
+
+        self._access_key = EnvIO.as_str(
+            'AWS_ACCESS_KEY', 'AWS_ACCESS_KEY_LOCAL')
+
+        self._secret_key = EnvIO.as_str(
+            'AWS_SECRET_KEY', 'AWS_SECRET_KEY_LOCAL')
 
     def access_key(self) -> str:
         return CryptoBase().decrypt_str(self._access_key)
