@@ -17,6 +17,10 @@ class FileContentWriter(BaseObject):
             craigtrim@gmail.com
             *   refactored out of 'persist-from-s3' in pursuit of
                 https://bast-ai.atlassian.net/browse/COR-72
+        Updated:
+            1-Nov-2022
+            craigtrim@gmail.com
+            *   add file-data null check
         """
         BaseObject.__init__(self, __name__)
 
@@ -25,12 +29,16 @@ class FileContentWriter(BaseObject):
                 file_path: str,
                 file_ext: str) -> None:
 
+        if not file_data or not len(file_data):
+            return None
+
         if file_ext in ['txt', 'owl', 'csv', 'tsv']:
-            FileIO.write_string(
-                input_text=file_data, file_path=file_path)
+            FileIO.write_string(input_text=file_data,
+                                file_path=file_path)
 
         elif file_ext in ['json', 'yaml', 'yml']:
-            FileIO.write_json(data=file_data, file_path=file_path)
+            FileIO.write_json(data=file_data,
+                              file_path=file_path)
 
         elif file_ext in ['jpg', 'png']:
             with open(file_path, 'wb') as f:
